#! /usr/bin/env python3

import argparse
import subprocess

from lxml import etree

# There is probably easier ways to express these...
title_xpath = "//*[local-name() = 'text'][@id='title']//*[local-name() = 'tspan']"
icon_xpath = "//*[local-name() = 'text'][@id='icon']//*[local-name() = 'tspan']"
accent_xpath = "//*[local-name() = 'path'][@id='path911']"

# stuff
TITLECARD_PATH = "titlecard.svg"
ICONS = {
    "lab": "",
    "code": "",
    "tools": "",
    "security": "",
    "games": "",
    "vcs": "",
    "talk": ""
}
COLOURS = {
    "main": "204a87",
    "extra": "ce5c00",
    "red": "a40000",
    "plum": "5c3566",
    "green": "4e9a06",
    "choc": "8f5902"
}

def patch_value(tree, path, newval):
    tree.xpath( path )[0].text = newval

def patch_attr(tree, path, attr, newval):
    tree.xpath( path )[0].set(attr, newval)

def generate_card(data):
    tree = etree.parse( data.titlecard )

    # patch the values
    full_title = ' '.join(data.title)
    patch_value(tree, title_xpath, full_title)
    patch_value(tree, icon_xpath, ICONS[data.icon])

    # corner
    fill_col = COLOURS[ data.fill ] if data.fill in COLOURS else data.fill
    new_style= "fill:#{};fill-opacity:1;fill-rule:evenodd".format(fill_col)
    patch_attr(tree, accent_xpath, "style", new_style)

    # generate a new SVG
    with open(data.out, "wb") as f:
        tree.write(f, pretty_print=True)

    # generate a png
    subprocess.run(["inkscape", "--export-type=png", data.out])

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('icon', choices=ICONS.keys())
    parser.add_argument('title', nargs='+')
    parser.add_argument('--fill', default="main")
    parser.add_argument('--titlecard', default=TITLECARD_PATH)
    parser.add_argument('--out', default="title-gen.svg")
    parser.add_argument('--png', default=True, type=bool)

    args = parser.parse_args()
    generate_card(args)

if __name__ == '__main__':
    main()
